@@ -1,5 +1,5 @@
 # MODULES
-from typing import Optional
+from typing import Dict, List, Optional
 
 # PYDANTIC
 from pydantic import BaseModel, ConfigDict, Field
@@ -15,3 +15,6 @@ class OpenApiSchema(BaseModel):
 
     description: Optional[str] = Field(default=None)
     contact: Optional[ContactSchema] = Field(default=None)
+    swagger_favicon_url: Optional[str] = Field(default=None)
+    redoc_favicon_url: Optional[str] = Field(default=None)
+    tags: List[Dict[str, str]] = Field(default_factory=lambda: [])
